# -*- coding: utf-8 -*-
from setuphelpers import *
import platform

uninstallkey = []

# Declaring specific app values (TO CHANGE)
bin_name_deb_string = 'google-chrome-stable-%s_amd64.deb'
bin_name_rpm_string = 'google-chrome-stable-%s_x86_64.rpm'
package_name = 'google-chrome-stable'
deb_source = makepath('/','etc','apt','sources.list.d','google-chrome.list')
yum_source = makepath('/','etc','yum.repos.d','google-chrome.list')


def install():
    # Declaring specific app values
    package_version = control['version'].split('-',1)[0]
    bin_name_deb = bin_name_deb_string % package_version
    bin_name_rpm = bin_name_rpm_string  % package_version

    isapt = True
    try:
        run('apt-get --version')
    except:
        isapt = False

    # Installing the package
    if isapt:
        print('Installing %s' % bin_name_deb)
        try:
            install_deb(bin_name_deb)
        except:
            install_required_dependencies_apt()
            install_deb(bin_name_deb)
    else:
        print('Installing %s' % bin_name_rpm)
        install_yum(bin_name_rpm)

    # Deleting sources files
    if isfile(deb_source):
        print('Removing ' + deb_source)
        remove_file(deb_source)
    if isfile(yum_source):
        print('Removing ' + yum_source)
        remove_file(yum_source)


def uninstall():
    # Uninstalling the package
    if platform.linux_distribution()[0].lower() in ['debian','ubuntu']:
        print('Uninstalling %s' % package_name)
        uninstall_apt(package_name)

    if platform.linux_distribution()[0].lower() in ['centos linux','centos','suse','fedora','redhat']:
        print('Uninstalling %s' % package_name)
        uninstall_yum(package_name)


def update_package():
    print('Download/Update package content from upstream binary sources')
    import json,platform

    # Getting proxy informations from WAPT settings
    proxy = {}
    if platform.system()=='Windows' and isfile(makepath(user_local_appdata(),'waptconsole','waptconsole.ini')):
        proxywapt = inifile_readstring(makepath(user_local_appdata(),'waptconsole','waptconsole.ini'),'global','http_proxy')
        if proxywapt :
            proxy = {'http':proxywapt,'https':proxywapt}

    # Specific app values
    app_name = control.name
    url_api = 'http://omahaproxy.appspot.com/all.json?os=win64&channel=stable'

    # Getting latest informations from GitHub API
    json_load = json.loads(wgets(url_api,proxies=proxy))
    version = json_load[0]['versions'][0]['version']


    latest_bin_deb = bin_name_deb_string % version
    latest_bin_yum = bin_name_rpm_string % version

    url_dl_deb = 'https://dl.google.com/linux/direct/google-chrome-stable_current_amd64.deb'
    url_dl_yum = 'https://dl.google.com/linux/direct/google-chrome-stable_current_x86_64.rpm'
    
    print('Latest ' + app_name + ' version is: ' + version)
    print('Download url for Debian is: ' + url_dl_deb)
    print('Download url for RedHat is: ' + url_dl_yum)

    # Downloading latest binaries
    if not isfile(latest_bin_deb):
        print('Downloading: ' + latest_bin_deb)
        wget(url_dl_deb,latest_bin_deb,proxies=proxy)
        
    if not isfile(latest_bin_yum):
        print('Downloading: ' + latest_bin_yum)
        wget(url_dl_yum,latest_bin_yum,proxies=proxy)

		# Change version of the package
        pe = PackageEntry().load_control_from_wapt('.')
        pe.version = '%s-%s'%(version,int(pe.version.split('-',1)[1])+1)
        pe.save_control_to_wapt('.')
        print('Changing version to ' + pe.version + ' in WAPT\\control')
        print('Update package done. You can now build-upload your package')
    else:
        print('This package is already up-to-date') 

    # Deleting outdated binaries
    for bin_in_dir in glob.glob('*.deb'):
        if latest_bin_deb != bin_in_dir :
            print('Outdated binary: ' + bin_in_dir + ' Deleted')
            remove_file(bin_in_dir)

    # Deleting outdated binaries
    for bin_in_dir in glob.glob('*.rpm'):
        if latest_bin_yum != bin_in_dir :
            print('Outdated binary: ' + bin_in_dir + ' Deleted')
            remove_file(bin_in_dir)

